@@ -5,7 +5,6 @@ from stripe.api_resources.abstract import DeletableAPIResource
 from stripe.api_resources.abstract import UpdateableAPIResource
 from stripe.api_resources.account import Account
 from stripe.api_resources.customer import Customer
-from stripe.api_resources.recipient import Recipient
 from stripe.six.moves.urllib.parse import quote_plus
 
 
@@ -15,9 +14,8 @@ class Card(DeletableAPIResource, UpdateableAPIResource):
 
 async def modify_patch(cls, sid, **params):
     raise NotImplementedError(
-        "Can't modify a card without a customer, recipient or account "
-        "ID. Call save on customer.sources.retrieve('card_id'), "
-        "recipient.cards.retrieve('card_id'), or "
+        "Can't modify a card without a customer or account "
+        "ID. Call save on customer.sources.retrieve('card_id'), or "
         "account.external_accounts.retrieve('card_id') instead."
     )
 
@@ -31,9 +29,8 @@ async def retrieve_patch(
     **params
 ):
     raise NotImplementedError(
-        "Can't retrieve a card without a customer, recipient or account "
-        "ID. Use customer.sources.retrieve('card_id'), "
-        "recipient.cards.retrieve('card_id'), or "
+        "Can't retrieve a card without a customer, or account "
+        "ID. Use customer.sources.retrieve('card_id'), or"
         "account.external_accounts.retrieve('card_id') instead."
     )
 
